function D = matcoef(A,p)
%MATCOEF Polynomial matrix with symbolic coefficient to matrix of coefficients.
%	MATCOEF(A,p) returns matrix of symbolic coefficients.
%	A is polynomial matrix in variable p.
%
%	Example: A =
%		 [ a*s^2+b*s+1,         s+b]
%		 [       a*b*s,         b+c]
%		 Ac = matcoef(A,s) returns
%		 Ac =
%		 [   1,   b,   b,   1,   a,   0]
%		 [   0, b+c, a*b,   0,   0,   0].

%    Authors: A. Klimentova, M. Sebek  January 22, 2002.

if nargin ~= 2
   error('Wrong number of input arguments')
end
if ~strcmp(class(A),'sym') & ~strcmp(class(A),'double')
   error('Input matrix must be of class sym')
end

% Finds matrix degree
degA=matdeg(A,p);
if degA==-inf
   degA=0;
end
i=1;
[Ax,Ay]=size(A);
D=[];

% Computes coefficients of the matrix
while ~isequal(i,degA+2),
   if i==1
      D=[subs(A,p,'0')];
   else
      D=[D subs(A,p,'0')];
   end
   if i>2
      D(:,i*Ay-Ay+1:i*Ay)=D(:,i*Ay-Ay+1:i*Ay)/factorial(i-1);
   end   
   A=diff(A,p);
   i=i+1;
end   
