function deg = matdeg(A,p,opt)
%MATDEG Various degree matrices of a polynomial matrix with symbolic coefficients:
%
%  D = matdeg(A,p)       returns the degree of the polynomial matrix A in variable p	
%  D = matdeg(A,p,'r')   returns a column vector containing the row degrees of A
%  D = matdeg(A,p,'c')   returns a row vector containing the column degrees of A
%  D = matdeg(A,p,'all') returns a matrix containing the degrees of the entries of A
%
% See also POL/DEG.

%    Authors:  A. Klimentova, M. Sebek  January 22, 2002.

if nargin > 3
   error('Too many input arguments')
elseif nargin < 2
   error('Not enough input arguments')
elseif nargin == 3 & ~strcmp(opt,'c') & ~strcmp(opt,'r') & ~strcmp(opt,'all')
   error('Not a valid option')
end
if ~strcmp(class(A),'sym') & ~strcmp(class(A),'double')
   error('Input matrix must be of class sym or double')
end

[Ax,Ay]=size(A);
cdeg=0;

% Finds degree of each polynomial
for i=1:Ax*Ay,
   AA(i)=maple('degree',A(i),p);
   if AA(i)=='-inf'
   	AA(i)=0;
	end
end
AAA=double(reshape(AA,Ax,Ay));
if nargin==3
   if opt=='r'    % finds row degrees
   	for j=1:Ax,
         deg(j)=max(AAA(j,:));  
      end
      deg=deg';
	elseif opt=='c'  % finds column degrees
   	for j=1:Ay,
   		deg(j)=max(AAA(:,j));
	   end
	elseif opt=='all'  % finds degrees of all entries
      deg=AAA;
	else
   	deg=AAA(opt);
   end
else   % finds maximum matrix degree
   deg=0;
   for j=1:Ax*Ay,
      if double(AA(j))>deg
         deg=double(AA(j));
      end
   end;
end




   
   
