%SHERMFUJI      Hermite-Fujiwara matrix with symbolic or numerical coefficients 
% of a polynomial
% The instruction
%   H = SHERMFUJI(P)
% computes the Hermite-Fujiwara matrix of continuous-time scalar 
% polynomial P with numerical coefficients. The polynomial P is asymtotically 
% stable if and only if the Hermite-Fujiwara matrix H is positive definite.
% The instruction
%   H = SHERMFUJI(P,Q)
%-----<<< END >>>-----
syms s a b c d e f g h;
p1 = a + b*s + c*s^2 + d*s^3 + e*s^4 + f*s^5 + g*s^6 + h*s^7
p2 = 1 + s - 12*s^2 - 28*s^3 - 16*s^4 + 5*s^5 + 14*s^6 - 3*s^7
w1 = shermfuji(p1,s)
subs(w1,{a,b,c,d,e,f,g,h},{1,1,-12,-28,-16,5,14,-3})
w2 = shermfuji(p2)
%+++++++++++++++++++++++++++++++++++++++++++++++++++++
%+++++++++++++++++++++++++++++++++++++++++++++++++++++
%SSCHURCOHN     Schur-Cohn matrix with symbolic or numerical coefficients 
% of a polynomial
% The instruction
%   S = SSCHURCOHN(P)
% computes the symmetric Schur-Cohn matrix of discrete-time scalar
% polynomial P with numerical coefficients. Matrix S is positive definite 
% if and only if P has all its zeros within the unit disk.
% The instruction
%   S = SSCHURCOHN(P,Q)
% computes the symmetric Schur-Cohn matrix of discrete-time scalar
% polynomial P with symbolic coefficients.
% A second argument Q may be specified in which variable is polynomial P.
syms u0 u1 u2 u3 u4 u5 u6 u7 z;
a1 = u0*z^3 + u1*z^2 + u2*z + u3
a3 = u7 + u6*z + u5*z^2 + u4*z^3 + u3*z^4 + u2*z^5 + u1*z^6 + u0*z^7 
a2 = 2*z^3 + 4*z^2 - 5*z + 3
a4 = 10 + 4*z - 5*z^2 - 7*z^3 + 13*z^4 + 9*z^5 - 16*z^6 + 28*z^7 
w1 = sschurcohn(a1,z)
subs(w1,{u0,u1,u2,u3},{2,4,-5,3})
w2 = sschurcohn(a2)

%+++++++++++++++++++++++++++++++++++++++++++++++++++++
%+++++++++++++++++++++++++++++++++++++++++++++++++++++
%SBEZOUT
J = [0 0 1;0 1 0;1 0 0]


a = 5+s-3*s^2+s^3+2*s^4-5*s^5 
H1 = 1/2*J*bezout(a,a')*J
H2 = 1/2*J*hermfuji(a)*J
H3 = shermfuji(a)



%-----------------------------------------

syms s a0 a1 a2 a3 a4 a5
syms b0 b1 b2 b3 b4 b5

a = a5 + a4*s + a3*s^2 + a2*s^3 + a1*s^4 + a0*s^5
b = b5 + b4*s + b3*s^2 + b2*s^3 + b1*s^4 + b0*s^5

a_ = subs(a,s,-s)

B1 = sbezout(a,b,s)

SH1 = 1/2*J*sbezout(a,a_,s)*J
SH2 = shermfuji(a,s)

subs(B,{a0,a1,a2,a3,a4,a5},{-5,2,1,-3,1,5})
